dispose method
void
dispose()
Disposes the stream controller.
Call this method when the plugin is no longer needed to free resources.
Implementation
void dispose() {
_intentExecutionController.close();
}
Disposes the stream controller.
Call this method when the plugin is no longer needed to free resources.
void dispose() {
_intentExecutionController.close();
}