AppIntentsPlatform class abstract

The interface that implementations of app_intents must implement.

Platform implementations should extend this class rather than implement it as app_intents does not consider newly added methods to be breaking changes. Extending this class (using extends) ensures that the subclass will get the default implementation, while platform implementations that implements this interface will be broken by newly added AppIntentsPlatform methods.

Inheritance
  • Object
  • PlatformInterface
  • AppIntentsPlatform
Implementers

Constructors

AppIntentsPlatform()
Constructs a AppIntentsPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
onIntentExecution Stream<IntentExecutionRequest>
A stream of intent execution requests from the native platform.
no setter
pendingActionsStream Stream<String>
A stream of pending action notifications from native App Intents.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearCachedValue(String key) Future<void>
Clears a cached value from native storage.
clearOnscreenEntity() Future<void>
Clears the onscreen entity association set by setOnscreenEntity (#56).
configureStorage({required String appGroupIdentifier, String? storageIdentifier}) Future<void>
Configures shared storage for cross-process App Intents communication.
donateRelevantEntities(String entityIdentifier, List<Map<String, dynamic>> entities, {String? context}) Future<void>
Donates a set of contextually relevant entities to the system (#55).
getCachedValue(String key) Future
Retrieves a cached value from native storage.
getPlatformVersion() Future<String?>
Returns the current platform version.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processPendingActions() Future<bool>
Checks for pending intent actions cached by native App Intents.
registerEntityQueryHandler(String entityIdentifier, Future<List<Map<String, dynamic>>> handler(List<String> identifiers)) → void
Registers a handler for querying entities by their identifiers.
registerIntentHandler(String identifier, Future<Map<String, dynamic>> handler(Map<String, dynamic> params)) → void
Registers a handler for the specified intent.
registerSuggestedEntitiesHandler(String entityIdentifier, Future<List<Map<String, dynamic>>> handler()) → void
Registers a handler for providing suggested/default entities.
registerValueQueryHandler(String entityIdentifier, Future<List<Map<String, dynamic>>> handler(Map<String, dynamic> input)) → void
Registers a handler for an IntentValueQuery (#51).
setCachedValue(String key, dynamic value) Future<void>
Sets a cached value in native storage.
setOnscreenEntity(String entityIdentifier, String entityId, {String? title}) Future<void>
Binds the entity currently shown on screen to an NSUserActivity so Siri and Apple Intelligence can resolve references like "this" (#56).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance AppIntentsPlatform
The default instance of AppIntentsPlatform to use.
getter/setter pair