pendingActionsStream property

Stream<String> get pendingActionsStream

A stream of pending action notifications from native App Intents.

Emits the intent identifier when a cache-mode intent's perform() stores a pending action via setPendingAction(). Events are buffered on the native side until Dart subscribes.

Listen to this stream and call processPendingActions when an event arrives to deliver the cached action to the registered handler.

Implementation

Stream<String> get pendingActionsStream {
  throw UnimplementedError(
      'pendingActionsStream has not been implemented.');
}