requestIntentValue method

Future<Object?> requestIntentValue(
  1. String executionId,
  2. String parameter
)

Asks the running intent to prompt the user for a parameter value (#131).

Resolves once the user answers, so it can stay outstanding for as long as the system dialog is on screen.

Implementation

Future<Object?> requestIntentValue(String executionId, String parameter) {
  throw UnimplementedError('requestIntentValue() has not been implemented.');
}