app_intents library

Flutter plugin for iOS App Intents integration.

This plugin enables Flutter apps to integrate with iOS App Intents, allowing them to be controlled via Siri and Shortcuts.

Classes

AppIntents
Main class for interacting with iOS App Intents from Flutter.
AppIntentsPlatform
The interface that implementations of app_intents must implement.
IntentExecutionRequest
Represents a request to execute an intent from the native platform.

Enums

AppIntentErrorCode
Error codes for App Intent operations.

Typedefs

EntityQueryHandler = Future<List<Map<String, dynamic>>> Function(List<String> identifiers)
Type definition for entity query handler functions.
IntentHandler = Future<Map<String, dynamic>> Function(Map<String, dynamic> params)
Type definition for intent handler functions.
SuggestedEntitiesHandler = Future<List<Map<String, dynamic>>> Function()
Type definition for suggested entities handler functions.

Exceptions / Errors

AppIntentError
Represents an error that occurred during App Intent operations.