AppIntentError class
Represents an error that occurred during App Intent operations.
This class provides both a machine-readable code and a human-readable message for error handling and display.
- Implemented types
Constructors
-
AppIntentError({required String code, required String message, Map<
String, dynamic> ? details}) - Creates a new AppIntentError.
-
AppIntentError.fromCode(AppIntentErrorCode errorCode, {String? message, Map<
String, dynamic> ? details}) -
Creates an AppIntentError from a predefined error code.
factory
-
AppIntentError.fromMap(Map<
String, dynamic> map) -
Creates an AppIntentError from a map.
factory
Properties
- code → String
-
The error code identifying the type of error.
final
-
details
→ Map<
String, dynamic> ? -
Optional additional details about the error.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
A human-readable description of the error.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts this error to a map.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited