AppIntentsPlatform class abstract
The interface that implementations of app_intents must implement.
Platform implementations should extend this class rather than implement it
as app_intents does not consider newly added methods to be breaking
changes. Extending this class (using extends) ensures that the subclass
will get the default implementation, while platform implementations that
implements this interface will be broken by newly added
AppIntentsPlatform methods.
- Inheritance
-
- Object
- PlatformInterface
- AppIntentsPlatform
- Implementers
Constructors
- AppIntentsPlatform()
- Constructs a AppIntentsPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onIntentExecution
→ Stream<
IntentExecutionRequest> -
A stream of intent execution requests from the native platform.
no setter
-
pendingActionsStream
→ Stream<
String> -
A stream of pending action notifications from native App Intents.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearCachedValue(
String key) → Future< void> - Clears a cached value from native storage.
-
getCachedValue(
String key) → Future - Retrieves a cached value from native storage.
-
getPlatformVersion(
) → Future< String?> - Returns the current platform version.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
processPendingActions(
) → Future< bool> - Checks for pending intent actions cached by native App Intents.
-
registerEntityQueryHandler(
String entityIdentifier, Future< List< handler(List<Map< >String, dynamic> >String> identifiers)) → void - Registers a handler for querying entities by their identifiers.
-
registerIntentHandler(
String identifier, Future< Map< handler(Map<String, dynamic> >String, dynamic> params)) → void - Registers a handler for the specified intent.
-
registerSuggestedEntitiesHandler(
String entityIdentifier, Future< List< handler()) → voidMap< >String, dynamic> > - Registers a handler for providing suggested/default entities.
-
setCachedValue(
String key, dynamic value) → Future< void> - Sets a cached value in native storage.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ AppIntentsPlatform
-
The default instance of AppIntentsPlatform to use.
getter/setter pair