processPendingActions method

Future<bool> processPendingActions()

Checks for pending intent actions cached by native App Intents.

Call this after all intent handlers are registered. Pending actions are delivered via the existing executeIntent mechanism. Returns true if a pending action was found and delivered.

Implementation

Future<bool> processPendingActions() {
  throw UnimplementedError(
      'processPendingActions() has not been implemented.');
}